﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TechNote51_SmartIO123_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private int m_iPwm1Duty;
        private int m_iPwm2Duty;

        private int m_iDACChannel = 0;
        public bool m_bPreB6Status;
        public bool m_bPreB7Status;
        private int m_iPWMChannel;

        private void Form1_Load(object sender, EventArgs e)
        {
            Form2 frm2 = new Form2();

            // 현재 Form을 MainForm으로 설정합니다.
            smartForm1.MainForm = this;
            // MainForm에 Child Form을 추가합니다.
            smartForm1.AddChildForm(frm2);
            smartForm1.ChildFormLocation(105, 54);

            // 초기 PWM1, 2의 Duty 값 설정 및 표시
            smartPWM1.SetCarryFrequency1(SmartX.SmartPWM.CLOCKDIVIDER.DIVIDE2, 33, 500);
            smartPWM1.DutyRate1 = 50;
            smartPWM1.SetCarryFrequency2(SmartX.SmartPWM.CLOCKDIVIDER.DIVIDE2, 33, 500);
            smartPWM1.DutyRate2 = 50;

            m_iPwm1Duty = 50;
            m_iPwm2Duty = 50;

            // SmartUpDown의 Button을 누르고 있을 때 가속 모드로 점점 빨라지도록 설정
            udPWM.SpecialFunction = SmartX.SmartButton.SPECIALFUNC.REPT;
            // 가속을 위한 RepeatAccelerate 설정
            SmartX.SmartButton.RepeatAccelerate[] repAcc = new SmartX.SmartButton.RepeatAccelerate[3];

            // 처음 Button의 클릭횟수 10회 동안은 Interval이 300ms
            repAcc[0].iClickCount = 10;
            repAcc[0].iInterval = 300;

            // 그다음 Button의 클릭횟수 10회 동안은 Interval이 100ms
            repAcc[1].iClickCount = 10;
            repAcc[1].iInterval = 100;

            // 그다음 Button의 클릭횟수 10회 동안은 Interval이 10ms
            repAcc[2].iClickCount = 10;
            repAcc[2].iInterval = 10;

            udPWM.RepeatIntervalAccelerate = repAcc;
            udDAC.RepeatIntervalAccelerate = repAcc;

            // SmartGPIO Port Select
            GPIO_PortA.PortSelect = SmartX.SmartGPIO.PORTID.PORTA;
            GPIO_PortB.PortSelect = SmartX.SmartGPIO.PORTID.PORTB;
            GPIO_PortC.PortSelect = SmartX.SmartGPIO.PORTID.PORTC;
            GPIO_PortD.PortSelect = SmartX.SmartGPIO.PORTID.PORTD;
            GPIO_PortE.PortSelect = SmartX.SmartGPIO.PORTID.PORTE;
            GPIO_PortF.PortSelect = SmartX.SmartGPIO.PORTID.PORTF;

            smartForm1.Show(0);
        }

        // Start 버튼 클릭
        private void btnStart_Click(object sender, EventArgs e)
        {
            // SmartGPIO
            // SmartGPIO 입력 신호 감지 시작
            GPIO_PortA.PortWatchStart();
            GPIO_PortB.PortWatchStart();
            GPIO_PortC.PortWatchStart();
            GPIO_PortD.PortWatchStart();
            GPIO_PortE.PortWatchStart();
            GPIO_PortF.PortWatchStart();

            // SmartADC
            // ADC값을 읽어오는 Timer를 시작
            smartTimer1.Start();

            // SmartDAC
            // SmartDAC를 사용하기 전 PortB6,7이 Input이었다면 이전상태 저장
            if (btnPortDirB6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                m_bPreB6Status = true;
            }
            if (btnPortDirB7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                m_bPreB7Status = true;
            }

            // 선택된 DAC Port
            if (radDAC1.Checked == true)
            {
                m_iDACChannel = 1;
            }
            else if (radDAC2.Checked == true)
            {
                m_iDACChannel = 2;
            }

            if (m_iDACChannel != 0)
            {
                // DAC를 사용하기 위해 Port B6, B7 방향을 OUTPUT으로 설정
                GPIO_PortB.DirPin6 = SmartX.SmartGPIO.PINDIR.OUTPUT;
                GPIO_PortB.DirPin7 = SmartX.SmartGPIO.PINDIR.OUTPUT;
                btnPortDirB6.ButtonDown();
                btnPortDirB7.ButtonDown();
            }

            // SmartPWM 기능
            // 선택된 PWM Port
            m_iPWMChannel = (radPWM1.Checked == true) ? 1 : 2;
            if (m_iPWMChannel == 1)
            {
                smartPWM1.StartPWM1();
            }
            else
            {
                smartPWM1.StartPWM2();
            }
        }

        // Stop 버튼 클릭
        private void btnStop_Click(object sender, EventArgs e)
        {
            // SmartGPIO
            // SmartGPIO 입력 신호 감지 중지
            GPIO_PortA.PortWatchStop();
            GPIO_PortB.PortWatchStop();
            GPIO_PortC.PortWatchStop();
            GPIO_PortD.PortWatchStop();
            GPIO_PortE.PortWatchStop();
            GPIO_PortF.PortWatchStop();

            // SmartADC
            // ADC값을 읽어오는 Timer를 중지
            smartTimer1.Stop();

            // SmartDAC
            // SmartDAC를 사용하기 전 PortB6, B7이 INPUT이였으면 다시 이전상태로 설정
            if (m_bPreB6Status == true)
            {
                GPIO_PortB.DirPin6 = SmartX.SmartGPIO.PINDIR.INPUT;
                btnPortDirB6.ButtonUp();
            }
            if (m_bPreB7Status == true)
            {
                GPIO_PortB.DirPin7 = SmartX.SmartGPIO.PINDIR.INPUT;
                btnPortDirB7.ButtonUp();
            }

            // SmartPWM
            if (m_iPWMChannel == 1)
            {
                smartPWM1.StopPWM1();
            }
            else
            {
                smartPWM1.StopPWM2();
            }
        }

        // Set Apply 버튼 클릭.
        private void btnSetApply_Click(object sender, EventArgs e)
        {
            int iPortDirA;
            int iPortDirB;
            int iPortDirC;
            int iPortDirD;
            int iPortDirE;
            int iPortDirF;

            // Port-A를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirA = (btnPortDirA0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirA |= ((btnPortDirA1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirA |= ((btnPortDirA2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirA |= ((btnPortDirA3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirA |= ((btnPortDirA4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirA |= ((btnPortDirA5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirA |= ((btnPortDirA6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirA |= ((btnPortDirA7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortA.PortDirs = iPortDirA;
            iPortDirA = 0;

            // Port-B를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirB = (btnPortDirB0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirB |= ((btnPortDirB1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirB |= ((btnPortDirB2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirB |= ((btnPortDirB3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirB |= ((btnPortDirB4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirB |= ((btnPortDirB5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirB |= ((btnPortDirB6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirB |= ((btnPortDirB7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortB.PortDirs = iPortDirB;
            iPortDirB = 0;

            // Port-C를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirC = (btnPortDirC0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirC |= ((btnPortDirC1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirC |= ((btnPortDirC2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirC |= ((btnPortDirC3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirC |= ((btnPortDirC4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirC |= ((btnPortDirC5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirC |= ((btnPortDirC6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirC |= ((btnPortDirC7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortC.PortDirs = iPortDirC;
            iPortDirC = 0;

            // Port-D를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirD = (btnPortDirD0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirD |= ((btnPortDirD1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirD |= ((btnPortDirD2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirD |= ((btnPortDirD3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirD |= ((btnPortDirD4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirD |= ((btnPortDirD5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirD |= ((btnPortDirD6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirD |= ((btnPortDirD7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortD.PortDirs = iPortDirD;
            iPortDirD = 0;

            // Port-E를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirE = (btnPortDirE0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirE |= ((btnPortDirE1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirE |= ((btnPortDirE2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirE |= ((btnPortDirE3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirE |= ((btnPortDirE4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirE |= ((btnPortDirE5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirE |= ((btnPortDirE6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirE |= ((btnPortDirE7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortE.PortDirs = iPortDirE;
            iPortDirE = 0;

            // Port-F를 선택한 경우
            // Outout : 1 or Input : 0
            iPortDirF = (btnPortDirF0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0;
            iPortDirF |= ((btnPortDirF1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 1;
            iPortDirF |= ((btnPortDirF2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 2;
            iPortDirF |= ((btnPortDirF3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 3;
            iPortDirF |= ((btnPortDirF4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 4;
            iPortDirF |= ((btnPortDirF5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 5;
            iPortDirF |= ((btnPortDirF6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 6;
            iPortDirF |= ((btnPortDirF7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN) ? 1 : 0) << 7;
            GPIO_PortF.PortDirs = iPortDirF;
            iPortDirF = 0;
        }

        // Port를 Output으로 설정 후 버튼을 누르면 해당 포트의 출력 상태 변경(Low/High)
        private void PortOutChange_Click(object sender, EventArgs e)
        {
            int iOutData = 0;
            int iOutDatas = 0;

            SmartX.SmartButton btn = (SmartX.SmartButton)sender;
            string strSelPortPin = btn.Name.Substring(13, 1);

            if (btn.ButtonText == "Low")
            {
                btn.ButtonText = "High";
                switch (strSelPortPin)
                {
                    case "0":
                        iOutData = 1;
                        break;
                    case "1":
                        iOutData = 2;
                        break;
                    case "2":
                        iOutData = 4;
                        break;
                    case "3":
                        iOutData = 8;
                        break;
                    case "4":
                        iOutData = 16;
                        break;
                    case "5":
                        iOutData = 32;
                        break;
                    case "6":
                        iOutData = 64;
                        break;
                    case "7":
                        iOutData = 128;
                        break;
                    default:
                        break;
                }
            }
            else
            {
                btn.ButtonText = "Low";
                switch (strSelPortPin)
                {
                    case "0":
                        iOutData = 0XFE;
                        break;
                    case "1":
                        iOutData = 0XFD;
                        break;
                    case "2":
                        iOutData = 0XFB;
                        break;
                    case "3":
                        iOutData = 0XF7;
                        break;
                    case "4":
                        iOutData = 0XEF;
                        break;
                    case "5":
                        iOutData = 0XDF;
                        break;
                    case "6":
                        iOutData = 0XBF;
                        break;
                    case "7":
                        iOutData = 0X7F;
                        break;
                }
            }

            string strSelPort = btn.Name.Substring(12, 1);

            switch (strSelPort)
            {
                case "A":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortA.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortA.PortDatas | iOutData;
                    }
                    GPIO_PortA.PortDatas = iOutDatas;
                    break;

                case "B":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortB.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortB.PortDatas | iOutData;
                    }
                    GPIO_PortB.PortDatas = iOutDatas;
                    break;

                case "C":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortC.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortC.PortDatas | iOutData;
                    }
                    GPIO_PortC.PortDatas = iOutDatas;
                    break;

                case "D":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortD.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortD.PortDatas | iOutData;
                    }
                    GPIO_PortD.PortDatas = iOutDatas;
                    break;

                case "E":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortE.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortE.PortDatas | iOutData;
                    }
                    GPIO_PortE.PortDatas = iOutDatas;
                    break;

                case "F":
                    if (btn.ButtonText == "Low")
                    {
                        iOutDatas = GPIO_PortF.PortDatas & iOutData;
                    }
                    else
                    {
                        iOutDatas = GPIO_PortF.PortDatas | iOutData;
                    }
                    GPIO_PortF.PortDatas = iOutDatas;
                    break;
            }
        }

        // PORT-A 감지 이벤트 처리 함수
        private void GPIO_PortA_OnPortDatasChange(int iPortDatas)
        {
            // PORT-A의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirA0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirA7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampA7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        // PORT-B 감지 이벤트 처리 함수
        private void GPIO_PortB_OnPortDatasChange(int iPortDatas)
        {
            // PORT-B의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirB0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirB7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampB7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        // PORT-C 감지 이벤트 처리 함수
        private void GPIO_PortC_OnPortDatasChange(int iPortDatas)
        {
            // PORT-C의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirC0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirC7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampC7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        // PORT-D 감지 이벤트 처리 함수
        private void GPIO_PortD_OnPortDatasChange(int iPortDatas)
        {
            // PORT-D의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirD0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirD7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampD7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        // PORT-E 감지 이벤트 처리 함수
        private void GPIO_PortE_OnPortDatasChange(int iPortDatas)
        {
            // PORT-E의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirE0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirE7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampE7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        // PORT-F 감지 이벤트 처리 함수
        private void GPIO_PortF_OnPortDatasChange(int iPortDatas)
        {
            // PORT-E의 각 핀 방향이 INPUT일 때 iPortDatas 값에 따른 Lamp On/Off
            if (btnPortDirF0.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF0.Image = ((iPortDatas & 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF1.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF1.Image = (((iPortDatas & 2) >> 1) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF2.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF2.Image = (((iPortDatas & 4) >> 2) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF3.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF3.Image = (((iPortDatas & 8) >> 3) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF4.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF4.Image = (((iPortDatas & 16) >> 4) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF5.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF5.Image = (((iPortDatas & 32) >> 5) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF6.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF6.Image = (((iPortDatas & 64) >> 6) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }

            if (btnPortDirF7.ButtonStatus == SmartX.SmartButton.BUTSTATUS.UP)
            {
                pbLampF7.Image = (((iPortDatas & 128) >> 7) == 1) ? Properties.Resources.on_led : Properties.Resources.off_led;
            }
        }

        private void smartTimer1_Tick(object sender, EventArgs e)
        {
            // 100ms 마다 Timer1의 tick 이벤트가 발생하여 ADCDisplay()함수를 실행합니다.
            ADCDisplay();
        }

        // ADC 입력값을 확인하는 메서드
        private void ADCDisplay()
        {
            int iChannel = 0;
            int iADCData;

            // 현재 선택된 아날로그 입력 채널을 확인합니다.
            if (radADC1.Checked == true)
            { iChannel = 0; }
            else if (radADC2.Checked == true)
            { iChannel = 1; }
            else if (radADC3.Checked == true)
            { iChannel = 2; }
            else if (radADC4.Checked == true)
            { iChannel = 3; }
            else if (radADC5.Checked == true)
            { iChannel = 4; }
            else if (radADC6.Checked == true)
            { iChannel = 5; }

            // 선택된 채널의 A/D변환 값을 얻습니다.
            iADCData = smartADC1.ReadData(iChannel);

            // 레이블에 결과를 출력합니다.
            labADC.Text = iADCData.ToString();
        }

        // DAC 선택된 채널로 현재 설정된 값으로 출력 변경
        private void DACValueChange(object sender, EventArgs e)
        {
            if (m_iDACChannel == 1)
            {
                smartDAC1.DAC_Output(SmartX.SmartDAC.DACOUTCHANNEL.DAC_CHANNEL1, (int)udDAC.Value);
            }
            else
            {
                smartDAC1.DAC_Output(SmartX.SmartDAC.DACOUTCHANNEL.DAC_CHANNEL2, (int)udDAC.Value);
            }
        }

        // PWM Duty값 증가 버튼
        private void udPWM_OnUpButtonClick(object sender, EventArgs e)
        {
            if (m_iPWMChannel == 1)
            {
                // 현재 PWM1의 Duty값을 1씩 증가 처리 
                m_iPwm1Duty = (m_iPwm1Duty < 100) ? ++m_iPwm1Duty : 100;
                smartPWM1.DutyRate1 = m_iPwm1Duty;
                udPWM.Value = m_iPwm1Duty;
            }
            else
            {
                // 현재 PWM2의 Duty값을 1씩 증가 처리 
                m_iPwm2Duty = (m_iPwm2Duty < 100) ? ++m_iPwm2Duty : 100;
                smartPWM1.DutyRate2 = m_iPwm2Duty;
                udPWM.Value = m_iPwm2Duty;
            }
        }

        // PWM Duty값 감소 버튼
        private void udPWM_OnDownButtonClick(object sender, EventArgs e)
        {
            if (m_iPWMChannel == 1)
            {
                // 현재 PWM1의 Duty값을 1씩 감소 처리 
                m_iPwm1Duty = (m_iPwm1Duty > 0) ? --m_iPwm1Duty : 0;
                smartPWM1.DutyRate1 = m_iPwm1Duty;
                udPWM.Value = m_iPwm1Duty;
            }
            else
            {
                // 현재 PWM2의 Duty값을 1씩 감소 처리 
                m_iPwm2Duty = (m_iPwm2Duty > 0) ? --m_iPwm2Duty : 0;
                smartPWM1.DutyRate2 = m_iPwm2Duty;
                udPWM.Value = m_iPwm2Duty;
            }
        }

        // FORM2 오픈. SmartInputCounter 테스트
        private void btnShowForm2_Click(object sender, EventArgs e)
        {
            // FORM2를 호출하기전에 A~F포트 사용중지
            btnStop_Click(sender, e);

            // FORM2 호출
            smartForm1.Show(1);
        }
    }
}
